<?php
/**
 * The Header for our theme.
 * @package Transport Movers
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width">
<link rel="profile" href="<?php echo esc_url( __( 'http://gmpg.org/xfn/11', 'transport-movers' ) ); ?>">
<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
<?php if(get_theme_mod('transport_movers_preloader',true)){ ?>
  <div class="frame">
    <div class="loader">
      <div class="dot-1"></div>
      <div class="dot-2"></div>
      <div class="dot-3"></div>
    </div>
  </div>
<?php }?>
<header role="banner">
  <a class="screen-reader-text skip-link" href="#skip_content"><?php esc_html_e( 'Skip to content', 'transport-movers' ); ?></a>
  <div class="topbar">
    <div class="container">
      <div class="row">
        <div class="col-lg-4 col-md-4">
          <div class="row">
            <?php if( get_theme_mod( 'transport_movers_call','' ) != '') { ?>
              <div class="col-lg-2 col-md-2">
                <i class="fas fa-phone"></i>
              </div>
              <div class="col-lg-10 col-md-10 pl-0">
                <p class="text"><?php echo esc_html( get_theme_mod('transport_movers_call','' )); ?></p>
                <p class="email"><?php echo esc_html( get_theme_mod('transport_movers_email','' )); ?></p>
              </div>
            <?php }?>
          </div>
        </div>
        <div class="col-lg-6 col-md-6">
          <div class="row">
            <?php if( get_theme_mod( 'transport_movers_city','' ) != '') { ?>
              <div class="col-lg-2 col-md-2">
                <i class="far fa-compass"></i>
              </div>
              <div class="col-lg-10 col-md-10 pl-0">
                <p class="text"><?php echo esc_html( get_theme_mod('transport_movers_city','' )); ?></p>
                <p class="city"><?php echo esc_html( get_theme_mod('transport_movers_location','' )); ?></p>
              </div>
            <?php }?>
          </div>
        </div>
        <?php if( get_theme_mod( 'transport_movers_button_link','' ) != '') { ?>
        <div class="col-lg-2 col-md-2 appointbtn p-0">
          <a href="<?php echo esc_url( get_theme_mod('transport_movers_button_link','#' ) ); ?>"><?php esc_html_e( 'Request Quote','transport-movers' ); ?><span class="screen-reader-text"><?php esc_html_e( 'Request Quote','transport-movers' );?></span></a>
        </div>
        <?php } ?>
      </div>
    </div>
  </div>
  <div id="header">
    <div class="container inner-box menus">
      <div class="row m-0">
        <div class="col-lg-3 col-md-6 col-9">
          <div class="logo">
            <?php if ( has_custom_logo() ) : ?>
              <div class="site-logo"><?php the_custom_logo(); ?></div>
            <?php endif; ?>
            <?php $blog_info = get_bloginfo( 'name' ); ?>
            <?php if ( ! empty( $blog_info ) ) : ?>
              <?php if ( is_front_page() && is_home() ) : ?>
                <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
              <?php else : ?>
                <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
              <?php endif; ?>
            <?php endif; ?>
            <?php
            $description = get_bloginfo( 'description', 'display' );
            if ( $description || is_customize_preview() ) :
              ?>
            <p class="site-description">
              <?php echo esc_html($description); ?>
            </p>
            <?php endif; ?>       
          </div>     
        </div>  
        <div class="col-lg-8 col-md-6 col-3 padding0">
          <div class="toggle-menu responsive-menu">
            <button role="tab" onclick="resMenu_open()"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','transport-movers'); ?></span>
            </button>
          </div>
          <div id="navbar-header" class="menu-brand">
            <div class="responsive-search">
              <?php get_search_form();?>
            </div>
            <nav id="site-navigation" class="primary-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'transport-movers' ); ?>">
              <a href="javascript:void(0)" class="closebtn responsive-menu" onclick="resMenu_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','transport-movers'); ?></span></a>
              <?php 
                wp_nav_menu( array( 
                  'theme_location' => 'primary',
                  'container_class' => 'main-menu-navigation clearfix' ,
                  'menu_class' => 'clearfix',
                  'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
                  'fallback_cb' => 'wp_page_menu',
                ) ); 
              ?>
            </nav>
            <?php if( get_theme_mod( 'transport_movers_call','' ) != '') { ?>
              <div class="email_text">
                <div class="row">                  
                  <div class="col-lg-3 col-md-3 col-3">
                    <i class="fas fa-phone"></i>
                  </div>
                  <div class="col-lg-9 col-md-9 pl-0 col-9">
                    <p class="text"><?php echo esc_html( get_theme_mod('transport_movers_call','' )); ?></p>
                    <p class="email"><?php echo esc_html( get_theme_mod('transport_movers_email','' )); ?></p>
                  </div>
                </div>
              </div>
            <?php }?>
            <?php if( get_theme_mod( 'transport_movers_city','' ) != '') { ?>
              <div class="city_text">
                <div class="row">
                  <div class="col-lg-3 col-md-3 col-3">
                    <i class="far fa-compass"></i>
                  </div>
                  <div class="col-lg-9 col-md-9 col-9 pl-0">
                    <p class="text"><?php echo esc_html( get_theme_mod('transport_movers_city','' )); ?></p>
                    <p class="city"><?php echo esc_html( get_theme_mod('transport_movers_location','' )); ?></p>
                  </div>
                </div>
              </div>
            <?php }?>
            <?php if( get_theme_mod( 'transport_movers_button_link','' ) != '') { ?>
              <div class="appointbtn">
                <a href="<?php echo esc_url( get_theme_mod('transport_movers_button_link','' ) ); ?>"><?php esc_html_e( 'Request Quote','transport-movers' ); ?><span class="screen-reader-text"><?php esc_html_e( 'Request Quote','transport-movers' );?></span></a>
              </div>
            <?php } ?>
          </div>
        </div>
        <div class="col-lg-1 col-md-1">
          <div class="search-box">
            <a href="#search"><i class="fa fa-search"></i><span class="screen-reader-text"><?php esc_html_e('Search','transport-movers'); ?></span></a>
          </div>
        </div>
      </div>
      <div id="search">
        <a class="close">X<span class="screen-reader-text"><?php esc_html_e('Close','transport-movers'); ?></span></a>
        <?php get_search_form(); ?>
      </div>
      </div>
    </div> 
</header>